@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 from modelparameters.parameterdict import ParameterDict
 from modelparameters.parameters import Param
+from modelparameters.utils import info
+from modelparameters.utils import list_timings
+from modelparameters.utils import Timer
 
 from gotran.codegeneration.codegenerators import CppCodeGenerator
-from gotran.common import info
-from gotran.common import list_timings
-from gotran.common import Timer
 from gotran.common.options import parameters
 from gotran.model.loadmodel import load_ode
 
